summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--CHANGES4
-rw-r--r--png.h10
2 files changed, 7 insertions, 7 deletions
diff --git a/CHANGES b/CHANGES
index 4a19f1e5b..95134a446 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2113,7 +2113,9 @@ version 1.4.0beta56 [April 25, 2009]
Renamed "gamma" to "png_gamma" in pngset.c to avoid "shadowed declaration"
warning about a global "gamma" variable in math.h on some platforms.
-version 1.4.0beta57 [April 25, 2009]
+version 1.4.0beta57 [May 2, 2009]
+ Removed prototype for png_freeptr() that was added in libpng-1.4.0beta24
+ but was never defined (again).
version 1.4.0betaN [future]
Build shared libraries with -lz and sometimes -lm.
diff --git a/png.h b/png.h
index 9cb4ddf0e..8e4477517 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.4.0beta57 - April 25, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.0beta57 - April 25, 2009: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -157,7 +157,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.4.0beta57, April 25, 2009, are
* Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -333,7 +333,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.4.0beta57"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.0beta57 - April 25, 2009\n"
+ " libpng version 1.4.0beta57 - May 2, 2009\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -1934,8 +1934,6 @@ extern PNG_EXPORT(png_voidp,png_malloc_warn) PNGARG((png_structp png_ptr,
/* Frees a pointer allocated by png_malloc() */
extern PNG_EXPORT(void,png_free) PNGARG((png_structp png_ptr, png_voidp ptr));
-extern PNG_EXPORT(void,png_freeptr) PNGARG((png_structp png_ptr,
- png_voidp *ptr));
/* Free data that was allocated internally */
extern PNG_EXPORT(void,png_free_data) PNGARG((png_structp png_ptr,
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.0beta57 - April 25, 2009
+ * libpng version 1.4.0beta57 - May 2, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.0beta57 - April 25, 2009: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.0beta57 - May 2, 2009: Glenn
* See also "Contributing Authors", below.
*
@@ -157,7 +157,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta57, April 25, 2009, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta57, May 2, 2009, are
* Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5